.. Django Notification System documentation master file, created by
   sphinx-quickstart on Mon Nov 30 11:57:15 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Easy NHL
========

.. include:: introduction.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   conference
   division
   schedule
   game
   team
   player



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`